@@ -12,88 +12,19 @@ namespace SebastianBergmann\PHPLOC;
 
 /**
  * PHPLOC code analyser.
- *
- * @since     Class available since Release 1.0.0
  */
 class Analyser
 {
     /**
-     * @var array
+     * @var Collector
      */
-    private $namespaces = [];
+    private $collector;
 
     /**
      * @var array
      */
     private $classes = [];
 
-    /**
-     * @var array
-     */
-    private $constants = [];
-
-    /**
-     * @var array
-     */
-    private $possibleConstantAccesses = [];
-
-    /**
-     * @var array
-     */
-    private $count = [
-        'files'                       => 0,
-        'loc'                         => 0,
-        'lloc'                        => 0,
-        'llocClasses'                 => 0,
-        'llocFunctions'               => 0,
-        'llocGlobal'                  => 0,
-        'cloc'                        => 0,
-        'ccn'                         => 0,
-        'ccnMethods'                  => 0,
-        'interfaces'                  => 0,
-        'traits'                      => 0,
-        'classes'                     => 0,
-        'abstractClasses'             => 0,
-        'concreteClasses'             => 0,
-        'functions'                   => 0,
-        'namedFunctions'              => 0,
-        'anonymousFunctions'          => 0,
-        'methods'                     => 0,
-        'publicMethods'               => 0,
-        'nonPublicMethods'            => 0,
-        'nonStaticMethods'            => 0,
-        'staticMethods'               => 0,
-        'constants'                   => 0,
-        'classConstants'              => 0,
-        'globalConstants'             => 0,
-        'testClasses'                 => 0,
-        'testMethods'                 => 0,
-        'ccnByLloc'                   => 0,
-        'llocByNof'                   => 0,
-        'methodCalls'                 => 0,
-        'staticMethodCalls'           => 0,
-        'instanceMethodCalls'         => 0,
-        'attributeAccesses'           => 0,
-        'staticAttributeAccesses'     => 0,
-        'instanceAttributeAccesses'   => 0,
-        'globalAccesses'              => 0,
-        'globalVariableAccesses'      => 0,
-        'superGlobalVariableAccesses' => 0,
-        'globalConstantAccesses'      => 0,
-        'classCcnMin'                 => 0,
-        'classCcnAvg'                 => 0,
-        'classCcnMax'                 => 0,
-        'classLlocMin'                => 0,
-        'classLlocAvg'                => 0,
-        'classLlocMax'                => 0,
-        'methodCcnMin'                => 0,
-        'methodCcnAvg'                => 0,
-        'methodCcnMax'                => 0,
-        'methodLlocMin'               => 0,
-        'methodLlocAvg'               => 0,
-        'methodLlocMax'               => 0
-    ];
-
     /**
      * @var array
      */
@@ -113,132 +44,41 @@ class Analyser
         '$HTTP_POST_FILES'  => true
     ];
 
-    /**
-     * @var array
-     */
-    private $classCcn = [];
-
-    /**
-     * @var array
-     */
-    private $classLloc = [];
-
-    /**
-     * @var array
-     */
-    private $methodCcn = [];
-
-    /**
-     * @var array
-     */
-    private $methodLloc = [];
+    public function __construct()
+    {
+        $this->collector = new Collector();
+    }
 
     /**
      * Processes a set of files.
      *
-     * @param  array $files
-     * @param  bool  $countTests
+     * @param array $files
+     * @param bool  $countTests
+     *
      * @return array
-     * @since  Method available since Release 1.2.0
      */
     public function countFiles(array $files, $countTests)
     {
-        if ($countTests) {
-            foreach ($files as $file) {
-                $this->preProcessFile($file);
-            }
-        }
-
-        $directories = [];
-
         foreach ($files as $file) {
-            $directory = dirname($file);
-
-            if (!isset($directories[$directory])) {
-                $directories[$directory] = true;
-            }
-
             $this->countFile($file, $countTests);
         }
 
-        $count = $this->count;
-
-        $count['directories']       = count($directories) - 1;
-        $count['namespaces']        = count($this->namespaces);
-        $count['classes']           = $count['abstractClasses'] +
-                                      $count['concreteClasses'];
-        $count['functions']         = $count['namedFunctions'] +
-                                      $count['anonymousFunctions'];
-        $count['constants']         = $count['classConstants'] +
-                                      $count['globalConstants'];
-        $count['attributeAccesses'] = $count['staticAttributeAccesses'] +
-                                      $count['instanceAttributeAccesses'];
-        $count['methodCalls']       = $count['staticMethodCalls'] +
-                                      $count['instanceMethodCalls'];
-        $count['llocGlobal']        = $count['lloc'] -
-                                      $count['llocClasses'] -
-                                      $count['llocFunctions'];
-        $count['ncloc']             = $count['loc'] - $count['cloc'];
-
-        foreach ($this->possibleConstantAccesses as $possibleConstantAccess) {
-            if (in_array($possibleConstantAccess, $this->constants)) {
-                $count['globalConstantAccesses']++;
-            }
-        }
-
-        $count['globalAccesses'] = $count['globalConstantAccesses'] +
-                                   $count['globalVariableAccesses'] +
-                                   $count['superGlobalVariableAccesses'];
-
-        if ($count['lloc'] > 0) {
-            $count['ccnByLloc'] = $count['ccn'] / $count['lloc'];
-        }
-
-        if (count($this->classCcn) > 0) {
-            $count['classCcnMin'] = min($this->classCcn);
-            $count['classCcnAvg'] = array_sum($this->classCcn) / count($this->classCcn);
-            $count['classCcnMax'] = max($this->classCcn);
-        }
-
-        if (count($this->methodCcn) > 0) {
-            $count['methodCcnMin'] = min($this->methodCcn);
-            $count['methodCcnAvg'] = array_sum($this->methodCcn) / count($this->methodCcn);
-            $count['methodCcnMax'] = max($this->methodCcn);
-        }
-
-        if (count($this->classLloc) > 0) {
-            $count['classLlocMin'] = min($this->classLloc);
-            $count['classLlocAvg'] = array_sum($this->classLloc) / count($this->classLloc);
-            $count['classLlocMax'] = max($this->classLloc);
-        }
-
-        if (count($this->methodLloc) > 0) {
-            $count['methodLlocMin'] = min($this->methodLloc);
-            $count['methodLlocAvg'] = array_sum($this->methodLloc) / count($this->methodLloc);
-            $count['methodLlocMax'] = max($this->methodLloc);
-        }
-
-        if ($count['functions'] > 0) {
-            $count['llocByNof'] = $count['llocFunctions'] / $count['functions'];
-        }
-
-        return $count;
+        return $this->collector->getPublisher()->toArray();
     }
 
     /**
      * Pre-processes a single file.
      *
      * @param string $filename
-     * @since Method available since Release 1.2.0
      */
     public function preProcessFile($filename)
     {
-        $tokens    = token_get_all(file_get_contents($filename));
-        $numTokens = count($tokens);
+        $tokens    = \token_get_all(\file_get_contents($filename));
+        $numTokens = \count($tokens);
         $namespace = false;
 
         for ($i = 0; $i < $numTokens; $i++) {
-            if (is_string($tokens[$i])) {
+            if (\is_string($tokens[$i])) {
                 continue;
             }
 
@@ -254,8 +94,8 @@ class Analyser
 
                     $className = $this->getClassName($namespace, $tokens, $i);
 
-                    if (isset($tokens[$i+4]) && is_array($tokens[$i+4]) &&
-                        $tokens[$i+4][0] == T_EXTENDS) {
+                    if (isset($tokens[$i + 4]) && \is_array($tokens[$i + 4]) &&
+                        $tokens[$i + 4][0] == T_EXTENDS) {
                         $parent = $this->getClassName($namespace, $tokens, $i + 4);
                     } else {
                         $parent = null;
@@ -275,14 +115,18 @@ class Analyser
      */
     public function countFile($filename, $countTests)
     {
-        $buffer              = file_get_contents($filename);
-        $this->count['loc'] += substr_count($buffer, "\n");
-        $tokens              = token_get_all($buffer);
-        $numTokens           = count($tokens);
+        if ($countTests) {
+            $this->preProcessFile($filename);
+        }
+
+        $buffer              = \file_get_contents($filename);
+        $this->collector->incrementLines(\substr_count($buffer, "\n"));
+        $tokens              = \token_get_all($buffer);
+        $numTokens           = \count($tokens);
 
         unset($buffer);
 
-        $this->count['files']++;
+        $this->collector->addFile($filename);
 
         $blocks            = [];
         $currentBlock      = false;
@@ -290,34 +134,32 @@ class Analyser
         $className         = null;
         $functionName      = null;
         $testClass         = false;
-        $currentClassData  = null;
-        $currentMethodData = null;
+        $this->collector->currentClassReset();
+        $isInMethod = false;
 
         for ($i = 0; $i < $numTokens; $i++) {
-            if (is_string($tokens[$i])) {
-                $token = trim($tokens[$i]);
+            if (\is_string($tokens[$i])) {
+                $token = \trim($tokens[$i]);
 
                 if ($token == ';') {
                     if ($className !== null && !$testClass) {
-                        $this->count['llocClasses']++;
-                        $currentClassData['lloc']++;
+                        $this->collector->currentClassIncrementLines();
 
                         if ($functionName !== null) {
-                            $currentMethodData['lloc']++;
+                            $this->collector->currentMethodIncrementLines();
                         }
                     } elseif ($functionName !== null) {
-                        $this->count['llocFunctions']++;
+                        $this->collector->incrementFunctionLines();
                     }
 
-                    $this->count['lloc']++;
+                    $this->collector->incrementLogicalLines();
                 } elseif ($token == '?' && !$testClass) {
                     if ($className !== null) {
-                        $this->count['ccnMethods']++;
-                        $currentClassData['ccn']++;
-                        $currentMethodData['ccn']++;
+                        $this->collector->currentClassIncrementComplexity();
+                        $this->collector->currentMethodIncrementComplexity();
                     }
 
-                    $this->count['ccn']++;
+                    $this->collector->incrementComplexity();
                 } elseif ($token == '{') {
                     if ($currentBlock == T_CLASS) {
                         $block = $className;
@@ -327,27 +169,24 @@ class Analyser
                         $block = false;
                     }
 
-                    array_push($blocks, $block);
+                    \array_push($blocks, $block);
 
                     $currentBlock = false;
                 } elseif ($token == '}') {
-                    $block = array_pop($blocks);
+                    $block = \array_pop($blocks);
 
                     if ($block !== false && $block !== null) {
                         if ($block == $functionName) {
                             $functionName = null;
 
-                            if ($currentMethodData !== null) {
-                                $this->methodCcn[]  = $currentMethodData['ccn'];
-                                $this->methodLloc[] = $currentMethodData['lloc'];
-                                $currentMethodData  = null;
+                            if ($isInMethod) {
+                                $this->collector->currentMethodStop();
+                                $isInMethod = false;
                             }
                         } elseif ($block == $className) {
                             $className         = null;
                             $testClass         = false;
-                            $this->classCcn[]  = $currentClassData['ccn'];
-                            $this->classLloc[] = $currentClassData['lloc'];
-                            $currentClassData  = null;
+                            $this->collector->currentClassReset();
                         }
                     }
                 }
@@ -355,15 +194,12 @@ class Analyser
                 continue;
             }
 
-            list ($token, $value) = $tokens[$i];
+            list($token, $value) = $tokens[$i];
 
             switch ($token) {
                 case T_NAMESPACE:
                     $namespace = $this->getNamespaceName($tokens, $i);
-
-                    if (!isset($this->namespaces[$namespace])) {
-                        $this->namespaces[$namespace] = true;
-                    }
+                    $this->collector->addNamespace($namespace);
                     break;
 
                 case T_CLASS:
@@ -373,25 +209,26 @@ class Analyser
                         continue;
                     }
 
-                    $currentClassData = ['ccn' => 1, 'lloc' => 0];
+                    $this->collector->currentClassReset();
+                    $this->collector->currentClassIncrementComplexity();
                     $className        = $this->getClassName($namespace, $tokens, $i);
                     $currentBlock     = T_CLASS;
 
                     if ($token == T_TRAIT) {
-                        $this->count['traits']++;
+                        $this->collector->incrementTraits();
                     } elseif ($token == T_INTERFACE) {
-                        $this->count['interfaces']++;
+                        $this->collector->incrementInterfaces();
                     } else {
                         if ($countTests && $this->isTestClass($className)) {
                             $testClass = true;
-                            $this->count['testClasses']++;
+                            $this->collector->incrementTestClasses();
                         } else {
-                            if (isset($tokens[$i-2]) &&
-                                is_array($tokens[$i-2]) &&
-                                $tokens[$i-2][0] == T_ABSTRACT) {
-                                $this->count['abstractClasses']++;
+                            if (isset($tokens[$i - 2]) &&
+                                \is_array($tokens[$i - 2]) &&
+                                $tokens[$i - 2][0] == T_ABSTRACT) {
+                                $this->collector->incrementAbstractClasses();
                             } else {
-                                $this->count['concreteClasses']++;
+                                $this->collector->incrementConcreteClasses();
                             }
                         }
                     }
@@ -408,29 +245,29 @@ class Analyser
 
                     $next = $this->getNextNonWhitespaceTokenPos($tokens, $i);
 
-                    if (!is_array($tokens[$next]) && $tokens[$next] == '&') {
+                    if (!\is_array($tokens[$next]) && $tokens[$next] == '&') {
                         $next = $this->getNextNonWhitespaceTokenPos($tokens, $next);
                     }
 
-                    if (is_array($tokens[$next]) &&
+                    if (\is_array($tokens[$next]) &&
                         $tokens[$next][0] == T_STRING) {
                         $functionName = $tokens[$next][1];
                     } else {
                         $currentBlock = 'anonymous function';
                         $functionName = 'anonymous function';
-                        $this->count['anonymousFunctions']++;
+                        $this->collector->incrementAnonymousFunctions();
                     }
 
                     if ($currentBlock == T_FUNCTION) {
                         if ($className === null &&
                             $functionName != 'anonymous function') {
-                            $this->count['namedFunctions']++;
+                            $this->collector->incrementNamedFunctions();
                         } else {
                             $static     = false;
                             $visibility = T_PUBLIC;
 
                             for ($j = $i; $j > 0; $j--) {
-                                if (is_string($tokens[$j])) {
+                                if (\is_string($tokens[$j])) {
                                     if ($tokens[$j] == '{' ||
                                         $tokens[$j] == '}' ||
                                         $tokens[$j] == ';') {
@@ -459,23 +296,22 @@ class Analyser
 
                             if ($testClass &&
                                 $this->isTestMethod($functionName, $visibility, $static, $tokens, $i)) {
-                                $this->count['testMethods']++;
+                                $this->collector->incrementTestMethods();
                             } elseif (!$testClass) {
-                                $currentMethodData = ['ccn' => 1, 'lloc' => 0];
+                                $isInMethod = true;
+                                $this->collector->currentMethodStart();
 
                                 if (!$static) {
-                                    $this->count['nonStaticMethods']++;
+                                    $this->collector->incrementNonStaticMethods();
                                 } else {
-                                    $this->count['staticMethods']++;
+                                    $this->collector->incrementStaticMethods();
                                 }
 
                                 if ($visibility == T_PUBLIC) {
-                                    $this->count['publicMethods']++;
+                                    $this->collector->incrementPublicMethods();
                                 } else {
-                                    $this->count['nonPublicMethods']++;
+                                    $this->collector->incrementNonPublicMethods();
                                 }
-
-                                $this->count['methods']++;
                             }
                         }
                     }
@@ -483,12 +319,12 @@ class Analyser
 
                 case T_CURLY_OPEN:
                     $currentBlock = T_CURLY_OPEN;
-                    array_push($blocks, $currentBlock);
+                    \array_push($blocks, $currentBlock);
                     break;
 
                 case T_DOLLAR_OPEN_CURLY_BRACES:
                     $currentBlock = T_DOLLAR_OPEN_CURLY_BRACES;
-                    array_push($blocks, $currentBlock);
+                    \array_push($blocks, $currentBlock);
                     break;
 
                 case T_IF:
@@ -503,13 +339,12 @@ class Analyser
                 case T_BOOLEAN_OR:
                 case T_LOGICAL_OR:
                     if (!$testClass) {
-                        if ($currentMethodData !== null) {
-                            $this->count['ccnMethods']++;
-                            $currentClassData['ccn']++;
-                            $currentMethodData['ccn']++;
+                        if ($isInMethod) {
+                            $this->collector->currentClassIncrementComplexity();
+                            $this->collector->currentMethodIncrementComplexity();
                         }
 
-                        $this->count['ccn']++;
+                        $this->collector->incrementComplexity();
                     }
                     break;
 
@@ -518,22 +353,22 @@ class Analyser
                     // We want to count all intermediate lines before the token ends
                     // But sometimes a new token starts after a newline, we don't want to count that.
                     // That happend with /* */ and /**  */, but not with // since it'll end at the end
-                    $this->count['cloc'] += substr_count(rtrim($value, "\n"), "\n") + 1;
+                    $this->collector->incrementCommentLines(\substr_count(\rtrim($value, "\n"), "\n") + 1);
                     break;
                 case T_CONST:
-                    $this->count['classConstants']++;
+                    $this->collector->incrementClassConstants();
                     break;
 
                 case T_STRING:
                     if ($value == 'define') {
-                        $this->count['globalConstants']++;
+                        $this->collector->incrementGlobalConstants();
 
                         $j = $i + 1;
 
                         while (isset($tokens[$j]) && $tokens[$j] != ';') {
-                            if (is_array($tokens[$j]) &&
+                            if (\is_array($tokens[$j]) &&
                                 $tokens[$j][0] == T_CONSTANT_ENCAPSED_STRING) {
-                                $this->constants[] = str_replace('\'', '', $tokens[$j][1]);
+                                $this->collector->addConstant(\str_replace('\'', '', $tokens[$j][1]));
 
                                 break;
                             }
@@ -541,7 +376,7 @@ class Analyser
                             $j++;
                         }
                     } else {
-                        $this->possibleConstantAccesses[] = $value;
+                        $this->collector->addPossibleConstantAccesses($value);
                     }
                     break;
 
@@ -556,29 +391,29 @@ class Analyser
                          $tokens[$n][0] == T_VARIABLE) &&
                         $tokens[$nn] == '(') {
                         if ($token == T_DOUBLE_COLON) {
-                            $this->count['staticMethodCalls']++;
+                            $this->collector->incrementStaticMethodCalls();
                         } else {
-                            $this->count['instanceMethodCalls']++;
+                            $this->collector->incrementNonStaticMethodCalls();
                         }
                     } else {
                         if ($token == T_DOUBLE_COLON &&
                             $tokens[$n][0] == T_VARIABLE) {
-                            $this->count['staticAttributeAccesses']++;
+                            $this->collector->incrementStaticAttributeAccesses();
                         } elseif ($token == T_OBJECT_OPERATOR) {
-                            $this->count['instanceAttributeAccesses']++;
+                            $this->collector->incrementNonStaticAttributeAccesses();
                         }
                     }
                     break;
 
                 case T_GLOBAL:
-                    $this->count['globalVariableAccesses']++;
+                    $this->collector->incrementGlobalVariableAccesses();
                     break;
 
                 case T_VARIABLE:
                     if ($value == '$GLOBALS') {
-                        $this->count['globalVariableAccesses']++;
+                        $this->collector->incrementGlobalVariableAccesses();
                     } elseif (isset($this->superGlobals[$value])) {
-                        $this->count['superGlobalVariableAccesses']++;
+                        $this->collector->incrementSuperGlobalVariableAccesses();
                     }
                     break;
             }
@@ -586,19 +421,19 @@ class Analyser
     }
 
     /**
-     * @param  array  $tokens
-     * @param  int    $i
+     * @param array $tokens
+     * @param int   $i
+     *
      * @return string
-     * @since  Method available since Release 1.3.0
      */
     private function getNamespaceName(array $tokens, $i)
     {
-        if (isset($tokens[$i+2][1])) {
-            $namespace = $tokens[$i+2][1];
+        if (isset($tokens[$i + 2][1])) {
+            $namespace = $tokens[$i + 2][1];
 
-            for ($j = $i+3;; $j += 2) {
+            for ($j = $i + 3;; $j += 2) {
                 if (isset($tokens[$j]) && $tokens[$j][0] == T_NS_SEPARATOR) {
-                    $namespace .= '\\' . $tokens[$j+1][1];
+                    $namespace .= '\\' . $tokens[$j + 1][1];
                 } else {
                     break;
                 }
@@ -611,28 +446,23 @@ class Analyser
     }
 
     /**
-     * @param  string $namespace
-     * @param  array  $tokens
-     * @param  int    $i
+     * @param string $namespace
+     * @param array  $tokens
+     * @param int    $i
+     *
      * @return string
-     * @since  Method available since Release 1.3.0
      */
     private function getClassName($namespace, array $tokens, $i)
     {
-        $i         += 2;
-        $namespaced = false;
-
+        $i += 2;
         if (!isset($tokens[$i][1])) {
             return 'invalid class name';
         }
-
         $className  = $tokens[$i][1];
 
-        if ($className === '\\') {
-            $namespaced = true;
-        }
+        $namespaced = $className === '\\';
 
-        while (is_array($tokens[$i+1]) && $tokens[$i+1][0] !== T_WHITESPACE) {
+        while (\is_array($tokens[$i + 1]) && $tokens[$i + 1][0] !== T_WHITESPACE) {
             $className .= $tokens[++$i][1];
         }
 
@@ -640,18 +470,17 @@ class Analyser
             $className = $namespace . '\\' . $className;
         }
 
-        return strtolower($className);
+        return \strtolower($className);
     }
 
     /**
-     * @param  string $className
+     * @param string $className
+     *
      * @return bool
-     * @since  Method available since Release 1.2.0
      */
     private function isTestClass($className)
     {
         $parent = $this->classes[$className];
-        $result = false;
         $count  = 0;
 
         // Check ancestry for PHPUnit_Framework_TestCase.
@@ -664,9 +493,11 @@ class Analyser
             }
 
             if ($parent == 'phpunit_framework_testcase' ||
-                $parent == '\\phpunit_framework_testcase') {
-                $result = true;
-                break;
+                $parent == '\\phpunit_framework_testcase' ||
+                // TODO: Recognize PHPUnit\Framework\TestCase when it is imported
+                $parent == 'phpunit\\framework\\testcase' ||
+                $parent == '\\phpunit\\framework\\testcase') {
+                return true;
             }
 
             if (isset($this->classes[$parent]) && $parent !== $this->classes[$parent]) {
@@ -680,23 +511,17 @@ class Analyser
 
         // Fallback: Treat the class as a test case class if the name
         // of the parent class ends with "TestCase".
-        if (!$result) {
-            if (substr($this->classes[$className], -8) == 'testcase') {
-                $result = true;
-            }
-        }
-
-        return $result;
+        return \substr($this->classes[$className], -8) === 'testcase';
     }
 
     /**
-     * @param  string $functionName
-     * @param  int    $visibility
-     * @param  bool   $static
-     * @param  array  $tokens
-     * @param  int    $currentToken
+     * @param string $functionName
+     * @param int    $visibility
+     * @param bool   $static
+     * @param array  $tokens
+     * @param int    $currentToken
+     *
      * @return bool
-     * @since  Method available since Release 2.0.0
      */
     private function isTestMethod($functionName, $visibility, $static, array $tokens, $currentToken)
     {
@@ -704,7 +529,7 @@ class Analyser
             return false;
         }
 
-        if (strpos($functionName, 'test') === 0) {
+        if (\strpos($functionName, 'test') === 0) {
             return true;
         }
 
@@ -716,21 +541,22 @@ class Analyser
             --$currentToken;
         }
 
-        return strpos($tokens[$currentToken][1], '@test') !== false ||
-               strpos($tokens[$currentToken][1], '@scenario') !== false;
+        return \strpos($tokens[$currentToken][1], '@test') !== false ||
+               \strpos($tokens[$currentToken][1], '@scenario') !== false;
     }
 
     /**
-     * @param  array $tokens
-     * @param  int   $start
+     * @param array $tokens
+     * @param int   $start
+     *
      * @return bool
      */
     private function getNextNonWhitespaceTokenPos(array $tokens, $start)
     {
-        if (isset($tokens[$start+1])) {
-            if (isset($tokens[$start+1][0]) &&
-                $tokens[$start+1][0] == T_WHITESPACE &&
-                isset($tokens[$start+2])) {
+        if (isset($tokens[$start + 1])) {
+            if (isset($tokens[$start + 1][0]) &&
+                $tokens[$start + 1][0] == T_WHITESPACE &&
+                isset($tokens[$start + 2])) {
                 return $start + 2;
             } else {
                 return $start + 1;
@@ -741,16 +567,17 @@ class Analyser
     }
 
     /**
-     * @param  array $tokens
-     * @param  int   $start
+     * @param array $tokens
+     * @param int   $start
+     *
      * @return bool
      */
     private function getPreviousNonWhitespaceTokenPos(array $tokens, $start)
     {
-        if (isset($tokens[$start-1])) {
-            if (isset($tokens[$start-1][0]) &&
-                $tokens[$start-1][0] == T_WHITESPACE &&
-                isset($tokens[$start-2])) {
+        if (isset($tokens[$start - 1])) {
+            if (isset($tokens[$start - 1][0]) &&
+                $tokens[$start - 1][0] == T_WHITESPACE &&
+                isset($tokens[$start - 2])) {
                 return $start - 2;
             } else {
                 return $start - 1;
@@ -761,19 +588,17 @@ class Analyser
     }
 
     /**
-     * @param  array $tokens
-     * @param  int   $i
+     * @param array $tokens
+     * @param int   $i
+     *
      * @return bool
      */
     private function isClassDeclaration(array $tokens, $i)
     {
         $n = $this->getPreviousNonWhitespaceTokenPos($tokens, $i);
 
-        if (isset($tokens[$n]) && is_array($tokens[$n]) &&
-            $tokens[$n][0] == T_DOUBLE_COLON) {
-            return false;
-        }
-
-        return true;
+        return !isset($tokens[$n])
+            || !\is_array($tokens[$n])
+            || !\in_array($tokens[$n][0], [T_DOUBLE_COLON, T_NEW], true);
     }
 }
