@@ -18,14 +18,12 @@ use Symfony\Component\Console\Input\ArrayInput;
 
 /**
  * TextUI frontend for PHPLOC.
- *
- * @since     Class available since Release 2.0.0
  */
 class Application extends AbstractApplication
 {
     public function __construct()
     {
-        $version = new Version('3.0.1', dirname(dirname(__DIR__)));
+        $version = new Version('4.0.0', \dirname(\dirname(__DIR__)));
         parent::__construct('phploc', $version->getVersion());
     }
 
@@ -81,7 +79,7 @@ class Application extends AbstractApplication
 
         if (!$input->hasParameterOption('--quiet')) {
             $output->write(
-                sprintf(
+                \sprintf(
                     "phploc %s by Sebastian Bergmann.\n\n",
                     $this->getVersion()
                 )
@@ -102,15 +100,15 @@ class Application extends AbstractApplication
 
     private function disableXdebug()
     {
-        if (!extension_loaded('xdebug')) {
+        if (!\extension_loaded('xdebug')) {
             return;
         }
 
-        ini_set('xdebug.scream', 0);
-        ini_set('xdebug.max_nesting_level', 8192);
-        ini_set('xdebug.show_exception_trace', 0);
-        ini_set('xdebug.show_error_trace', 0);
+        \ini_set('xdebug.scream', 0);
+        \ini_set('xdebug.max_nesting_level', 8192);
+        \ini_set('xdebug.show_exception_trace', 0);
+        \ini_set('xdebug.show_error_trace', 0);
 
-        xdebug_disable();
+        \xdebug_disable();
     }
 }
